#region Copyright Syncfusion Inc. 2001 - 2006
//
//  Copyright Syncfusion Inc. 2001 - 2006. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

namespace TabbedMDI {

	using System;
	using System.ComponentModel;
	using System.Drawing;
	using System.Drawing.Text;
	using System.Windows.Forms;
    using Syncfusion.Windows.Forms.Tools;

	public class Document1 : System.Windows.Forms.Form
    {
        private IContainer components;
        private System.Windows.Forms.MainMenu mainMenu;
        private Syncfusion.Windows.Forms.Tools.DockingManager DOMLNA;

        private class FontSizes {
            public static float Small;
            public static float Medium;
            public static float Large;
			static FontSizes()
			{
				Small = 8f;
				Medium = 12f;
				Large = 24f;
			}
        }

        private float fontSize;
        
        private MenuItem miFormatFontChecked;
        private MenuItem miFormatSizeChecked;
        
        private MenuItem miSmall ;
        private MenuItem miMedium ;
        private MenuItem miLarge ;

        private MenuItem miSansSerif ;
        private MenuItem miSerif ;
        private MenuItem miMonoSpace ;

        private FontFamily currentFontFamily ;
        private FontFamily monoSpaceFontFamily;
        private FontFamily sansSerifFontFamily;
        protected RichTextBox richTextBox1;
        private CheckedListBox checkedListBox1;
        private FontFamily serifFontFamily;

        public Document1(string docName) : base() {

            //
            // Required for Windows Form Designer support
            //
            InitializeComponent();

			this.fontSize = FontSizes.Medium;

			//this.Icon = null;
            // Initialize Fonts - use generic fonts to avoid problems across
            // different versions of the OS
            monoSpaceFontFamily = new FontFamily (GenericFontFamilies.Monospace);
            sansSerifFontFamily = new FontFamily (GenericFontFamilies.SansSerif);
            serifFontFamily = new FontFamily (GenericFontFamilies.Serif);
            currentFontFamily = sansSerifFontFamily;
            
            this.Text = docName;

            richTextBox1.Font = new System.Drawing.Font(currentFontFamily, fontSize);
            richTextBox1.Text = docName;

            //Add Formatting Menu
            MenuItem miFormat = mainMenu.MenuItems.Add("F&ormat (" + docName + ")");
            miFormat.MergeType = MenuMerge.Add;
            miFormat.MergeOrder = 2;

            //Font Face sub-menu
            miSansSerif = new MenuItem("&1." + sansSerifFontFamily.Name, new EventHandler(this.FormatFont_Clicked));
            miSerif = new MenuItem("&2." + serifFontFamily.Name, new EventHandler(this.FormatFont_Clicked));
            miMonoSpace = new MenuItem("&3." + monoSpaceFontFamily.Name, new EventHandler(this.FormatFont_Clicked));
            miSansSerif.Checked = true ;
            miFormatFontChecked = miSansSerif ;
            miSansSerif.DefaultItem = true ;

            miFormat.MenuItems.Add( "Font &Face"
                        , (new MenuItem[]{ miSansSerif, miSerif, miMonoSpace })
                        );

            //Font Size sub-menu
            miSmall = new MenuItem("&Small", new EventHandler(this.FormatSize_Clicked));
            miMedium = new MenuItem("&Medium", new EventHandler(this.FormatSize_Clicked));
            miLarge = new MenuItem("&Large", new EventHandler(this.FormatSize_Clicked));
            miMedium.Checked = true ;
            miMedium.DefaultItem = true ;
            miFormatSizeChecked = miMedium ;

            miFormat.MenuItems.Add( "Font &Size"
                        , (new MenuItem[]{ miSmall, miMedium, miLarge })
                        );

        }

		~Document1()
		{
		}

        //File->Load Document Menu item handler
        protected void LoadDocument_Clicked(object sender, System.EventArgs e)
		{
            MessageBox.Show(this.Text) ;
        }

        //Format->Font Menu item handler
        protected void FormatFont_Clicked(object sender, System.EventArgs e) {
            MenuItem miClicked = (MenuItem)sender;
            miClicked.Checked = true;
            miFormatFontChecked.Checked = false;
            miFormatFontChecked = miClicked ;
            
            if (miClicked == miSansSerif) {        
                currentFontFamily = sansSerifFontFamily ;
            } else if (miClicked == miSerif) {
                currentFontFamily = serifFontFamily ;
            } else {
                currentFontFamily = monoSpaceFontFamily ;
            }
            
            richTextBox1.Font = new Font(currentFontFamily, fontSize);
        }

        //Format->Size Menu item handler
        protected void FormatSize_Clicked(object sender, System.EventArgs e) {
            MenuItem miClicked = (MenuItem)sender;
            miClicked.Checked = true;
            miFormatSizeChecked.Checked = false;
            miFormatSizeChecked = miClicked;
            
            if (miClicked == miSmall) {
                fontSize = FontSizes.Small ;
            } else if (miClicked == miLarge) {
                fontSize = FontSizes.Large ;
            } else {
                fontSize = FontSizes.Medium ;
            }

            richTextBox1.Font = new Font(currentFontFamily, fontSize);
        }

        /// <summary>
        ///    Clean up any resources being used.
        /// </summary>
        protected override void Dispose(bool disposing)
        {
            base.Dispose(disposing);
			if(components != null)
				components.Dispose();
        }


        /// <summary>
        ///    Required method for Designer support - do not modify
        ///    the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Document1));
            this.mainMenu = new System.Windows.Forms.MainMenu(this.components);
            this.richTextBox1 = new System.Windows.Forms.RichTextBox();
            this.checkedListBox1 = new System.Windows.Forms.CheckedListBox();
            this.SuspendLayout();
            // 
            // richTextBox1
            // 
            this.richTextBox1.Location = new System.Drawing.Point(0, 123);
            this.richTextBox1.Name = "richTextBox1";
            this.richTextBox1.Size = new System.Drawing.Size(213, 326);
            this.richTextBox1.TabIndex = 0;
            this.richTextBox1.Text = "";
            this.richTextBox1.Visible = false;
            // 
            // checkedListBox1
            // 
            this.checkedListBox1.FormattingEnabled = true;
            this.checkedListBox1.Location = new System.Drawing.Point(0, -1);
            this.checkedListBox1.Name = "checkedListBox1";
            this.checkedListBox1.Size = new System.Drawing.Size(168, 289);
            this.checkedListBox1.TabIndex = 14;
            // 
            // Document1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(442, 448);
            this.Controls.Add(this.checkedListBox1);
            this.Controls.Add(this.richTextBox1);
            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
            this.Menu = this.mainMenu;
            this.MinimizeBox = false;
            this.Name = "Document1";
            this.ShowInTaskbar = false;
            this.Load += new System.EventHandler(this.Document1_Load);
            this.ResumeLayout(false);

		}
        private void InitializeDockingWindows()
        {
            //try
            //{
                this.DOMLNA = new Syncfusion.Windows.Forms.Tools.DockingManager();
                this.DOMLNA.BeginInit();
                this.DOMLNA.HostControl = this;
                this.DOMLNA.ThemesEnabled = true;
                // this.DOMLNA.AutoHideActiveControl = true; 
                DockingManager.AnimationStep = 50;
                this.DOMLNA.VisualStyle = Syncfusion.Windows.Forms.VisualStyle.Office2003;
                this.DOMLNA.PersistState = false;
                this.DOMLNA.DisallowFloating = false; // windows should be dockable, amir
                this.DOMLNA.AutoHideInterval = 500; // To make docking panel quick in getting show/hide events (Less interval means more quick), amir               

                this.DOMLNA.DockControl(checkedListBox1, this, Syncfusion.Windows.Forms.Tools.DockingStyle.Left, 300);
                this.DOMLNA.SetDockLabel(checkedListBox1, ":: "+this.Text+" :Docking Panel");
                //this.DOMLNA.DockControl(pnlFilter, this, DockingStyle.Bottom, 250);
                //this.DOMLNA.SetDockLabel(pnlFilter, Utility.GetLocalizedText("LNAFilters", CommonVariables.CultureInfo));

                this.DOMLNA.EndInit();
            //}
            //catch (Exception objException)
            //{
            //    Utility.LogException(objException);
            //}
        }

        private void Document1_Load(object sender, EventArgs e)
        {
            InitializeDockingWindows();
        }

    }
}
